#cpimgs

## 1. Installation
_pip install cpimgs_

## 2. Instruction
Use this package to check drug corresponding plates and wells. \
1. The output is a python dictionary. \
2. The dict can be viewed in console by _print_ function.\
3. The plates and wells info can be viewed in console as well.
4. Images will be shown automatically by function _getPlotsByNameAndChn_

## 3. Note
The package is still actively under dev. The data is far from curated. Chemical names is a huge problem.

## 4. Disclaimer
The DMSO plots shown are random DMSO plots in the same well from the drug, not necessarily the representative ones.
